==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PA/ts/Arc2PA_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Arc2PA</name>
    <message>
        <location filename="../Arc2PA.js" line="+65"/>
        <source>Start point</source>
        <translatorcomment>--google--
Punkt początkowy (y):
Punkt początkowy (y)
Punkt początkowy (x):</translatorcomment>
        <translation type="unfinished">Punkt startowy</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End point</source>
        <translatorcomment>--google--
Punkt końcowy (x):
Punkt końcowy (x)
Punkt końcowy (y):</translatorcomment>
        <translation type="unfinished">Punkt końcowy</translation>
    </message>
    <message>
        <location line="+85"/>
        <source>Invalid angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Nieprawidłowy kąt</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Te dwa punkty są identyczne</translation>
    </message>
    <message>
        <location filename="../Arc2PA.ui" line="+17"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation type="unfinished">Kąt:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--
Kierunek widoku:</translatorcomment>
        <translation type="unfinished">Kierunek:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Counter Clockwise (Positive)</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Kierunek widoku:
Kierunek widoku
LTR</translatorcomment>
        <translation type="unfinished">Kierunek</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Ruchu wskazówek zegara (Negative)</translation>
    </message>
    <message>
        <location filename="../Arc2PAInit.js" line="+2"/>
        <source>&amp;2 Points and Angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">2 Punkty i kątowe</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narysuj łuk z 2 punktów i kąta</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PA/ts/Arc2PA_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Arc2PA</name>
    <message>
        <location filename="../Arc2PA.js" line="+65"/>
        <source>Start point</source>
        <translatorcomment>--google--
Punkt początkowy (y):
Punkt początkowy (y)
Punkt początkowy (x):</translatorcomment>
        <translation>Punkt początkowy</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End point</source>
        <translatorcomment>--google--
Punkt końcowy (x):
Punkt końcowy (x)
Punkt końcowy (y):</translatorcomment>
        <translation>Punkt końcowy</translation>
    </message>
    <message>
        <location line="+85"/>
        <source>Invalid angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nieprawidłowy kąt</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Te dwa punkty są takie same</translation>
    </message>
    <message>
        <location filename="../Arc2PA.ui" line="+17"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation>Kąt:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--
Kierunek widoku:</translatorcomment>
        <translation>Kierunek:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Przeciwnie do ruchu wskazówek zegara (w lewo)</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Kierunek widoku:
Kierunek widoku
LTR</translatorcomment>
        <translation>Kierunek</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zgodnie z ruchem wskazówek zegara (w lewo)</translation>
    </message>
    <message>
        <location filename="../Arc2PAInit.js" line="+2"/>
        <source>&amp;2 Points and Angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;2 punkty i kąt</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje łuk przez 2 punkty i o danym kącie</translation>
    </message>
</context>
</TS>
